package com.nisum.employeeservice.controller;

import com.nisum.employeeservice.exception.ResourceNotFoundException;
import com.nisum.employeeservice.model.Employee;
import com.nisum.employeeservice.service.EmployeeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@CrossOrigin(origins = "*")
@RestController
@RequestMapping("/api/v1")
public class EmployeeController {

  @Autowired EmployeeService employeeService;

  @GetMapping("/employees")
  public List<Employee> getAllEmployees() {
    return employeeService.findAllEmployees();
  }

  @PostMapping("/employees")
  public Employee createEmployee(@RequestBody Employee employee) {
    return employeeService.addEmployee(employee);
  }

  @GetMapping("/employees/{id}")
  public ResponseEntity<Employee> getEmployeeById(@PathVariable("id") Long id) throws ResourceNotFoundException {
    Employee employee = employeeService.findEmployeeById(id)
            .orElseThrow(() -> new ResourceNotFoundException("Employee Not found"));
    return ResponseEntity.ok().body(employee);
  }

  @PutMapping("/employees/{id}")
  public ResponseEntity<Employee> updateEmployeeById(@PathVariable("id") Long id, @RequestBody Employee employee) throws  ResourceNotFoundException {
    Employee updatedEmployee = employeeService.updateEmployee(id, employee);
    if (updatedEmployee == null) {
      throw new ResourceNotFoundException("Employee Not Found!");
    }
    return ResponseEntity.ok().body(employee);
  }

  @DeleteMapping("/employees/{id}")
  public ResponseEntity<Employee> deleteEmployee(@PathVariable("id") Long id) throws ResourceNotFoundException {
    Employee employee = employeeService.findEmployeeById(id)
            .orElseThrow(() -> new ResourceNotFoundException("Employee Not found"));
    employeeService.deleteEmployee(employee);
    return ResponseEntity.ok().body(employee);
  }
}
